( cd usr/lib64 ; rm -rf thunderbird )
( cd usr/lib64 ; ln -sf thunderbird-2.0.0.23 thunderbird )
( cd usr/bin ; rm -rf thunderbird )
( cd usr/bin ; ln -sf /usr/lib64/thunderbird-2.0.0.23/thunderbird thunderbird )
